===============================
kolla-kubernetes
===============================

Kubernetes deployment of the Kolla containers.

Kolla-Kubernetes is a project whose goal is to deploy Kolla's containers
with Kubernetes.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/kolla-kubernetes
* Source: http://git.openstack.org/cgit/openstack/kolla-kubernetes
* Bugs: http://bugs.launchpad.net/kolla-kubernetes
